@@ -1,12 +1,13 @@
 use strict;
 use warnings;
-package B::Hooks::Parser; # git description: 0.12-13-g9a2d0d6
+package B::Hooks::Parser; # git description: v0.19-16-gb88ab1c
 # ABSTRACT: Interface to perl's parser variables
+# KEYWORDS: perl internals API parser hooks modify
 
 use B::Hooks::OP::Check;
 use parent qw/DynaLoader/;
 
-our $VERSION = '0.13';
+our $VERSION = '0.20';
 
 sub dl_load_flags { 0x01 }
 
@@ -41,7 +42,7 @@ B::Hooks::Parser - Interface to perl's parser variables
 
 =head1 VERSION
 
-version 0.13
+version 0.20
 
 =head1 DESCRIPTION
 
@@ -103,6 +104,8 @@ except that they can't handle embedded C<NUL> bytes in strings.
 
 =head2 C<hook_op_check_id hook_parser_setup (void)>
 
+Note: may be implemented as a macro.
+
 =head2 C<void hook_parser_teardown (hook_op_check_id id)>
 
 =head2 C<const char *hook_parser_get_linestr (pTHX)>
@@ -115,13 +118,18 @@ except that they can't handle embedded C<NUL> bytes in strings.
 
 =head2 C<void hook_parser_clear_lex_stuff (pTHX)>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=B-Hooks-Parser>
+(or L<bug-B-Hooks-Parser@rt.cpan.org|mailto:bug-B-Hooks-Parser@rt.cpan.org>).
+
 =head1 AUTHOR
 
 Florian Ragwitz <rafl@debian.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Zefram Alexandr Ciornii Liu Kang-min
+=for stopwords Karen Etheridge Zefram Vincent Pit Alexandr Ciornii Karl Williamson Liu Kang-min
 
 =over 4
 
@@ -135,15 +143,23 @@ Zefram <zefram@fysh.org>
 
 =item *
 
+Vincent Pit <perl@profvince.com>
+
+=item *
+
 Alexandr Ciornii <alexchorny@gmail.com>
 
 =item *
 
+Karl Williamson <khw@cpan.org>
+
+=item *
+
 Liu Kang-min <gugod@gugod.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2008 by Florian Ragwitz.
 
