@@ -19,15 +19,16 @@
 
 #include "EXTERN.h"
 #include "perl.h"
-#define NEED_PL_parser
+#define NEED_sv_2pv_flags
 #include "ppport.h"
 
 /* the following #defines are stolen from assorted headers, not toke.c (mst) */
 
-#define skipspace(a)            S_skipspace(aTHX_ a)
+#define skipspace_flags(a,b)    S_skipspace(aTHX_ a)
+#define skipspace(a)            skipspace_flags(a, 0)
 #define incline(a)              S_incline(aTHX_ a)
 #define filter_gets(a,b,c)      S_filter_gets(aTHX_ a,b,c)
-#define scan_str(a,b,c)         S_scan_str(aTHX_ a,b,c)
+#define scan_str(a,b,c,d,e)     S_scan_str(aTHX_ a,b,c)
 #define scan_word(a,b,c,d,e)    S_scan_word(aTHX_ a,b,c,d,e)
 
 STATIC void     S_incline(pTHX_ char *s);
@@ -92,6 +93,7 @@ STATIC char*    S_scan_word(pTHX_ char *s, char *dest, STRLEN destlen, int allow
    declare the backcompat macros for things to still work (mst) */
 #define PL_lex_formbrack        (PL_parser->lex_formbrack)
 #define PL_lex_brackets         (PL_parser->lex_brackets)
+#define PL_lex_inwhat           (PL_parser->lex_inwhat)
 #define PL_sublex_info          (PL_parser->sublex_info)
 #define PL_oldoldbufptr         (PL_parser->oldoldbufptr)
 #define PL_oldbufptr            (PL_parser->oldbufptr)
@@ -127,7 +129,7 @@ static const char c_in_subst[] =
 /* Invoke the idxth filter function for the current rsfp.	 */
 /* maxlen 0 = read one text line */
 I32
-Perl_filter_read(pTHX_ int idx, SV *buf_sv, int maxlen)
+filter_read(pTHX_ int idx, SV *buf_sv, int maxlen)
 {
     filter_t funcp;
     SV *datasv = NULL;
@@ -242,7 +244,7 @@ S_skipspace(pTHX_ register char *s)
 	 * of the buffer, we're not reading from a source filter, and
 	 * we're in normal lexing mode
 	 */
-	if (s < PL_bufend || !PL_rsfp || PL_sublex_info.sub_inwhat ||
+	if (s < PL_bufend || !PL_rsfp || PL_lex_inwhat ||
 		PL_lex_state == LEX_FORMLINE)
 	    return s;
 
@@ -313,13 +315,15 @@ S_skipspace(pTHX_ register char *s)
 	 * so store the line into the debugger's array of lines
 	 */
 	if (PERLDB_LINE && PL_curstash != PL_debstash) {
-	    SV * const sv = NEWSV(85,0);
-
-	    sv_upgrade(sv, SVt_PVMG);
-	    sv_setpvn(sv,PL_bufptr,PL_bufend-PL_bufptr);
-            (void)SvIOK_on(sv);
-            SvIV_set(sv, 0);
-	    av_store(CopFILEAV(PL_curcop),(I32)CopLINE(PL_curcop),sv);
+	    AV *fileav = CopFILEAV(PL_curcop);
+	    if (fileav) {
+		SV * const sv = NEWSV(85,0);
+		sv_upgrade(sv, SVt_PVMG);
+		sv_setpvn(sv,PL_bufptr,PL_bufend-PL_bufptr);
+		(void)SvIOK_on(sv);
+		SvIV_set(sv, 0);
+		av_store(fileav,(I32)CopLINE(PL_curcop),sv);
+	    }
 	}
     }
 }
@@ -743,13 +747,15 @@ S_scan_str(pTHX_ char *start, int keep_quoted, int keep_delims)
 
 	/* update debugger info */
 	if (PERLDB_LINE && PL_curstash != PL_debstash) {
-	    SV *sv = NEWSV(88,0);
-
-	    sv_upgrade(sv, SVt_PVMG);
-	    sv_setsv(sv,PL_linestr);
-            (void)SvIOK_on(sv);
-            SvIV_set(sv, 0);
-	    av_store(CopFILEAV(PL_curcop), (I32)CopLINE(PL_curcop), sv);
+	    AV *fileav = CopFILEAV(PL_curcop);
+	    if (fileav) {
+		SV *sv = NEWSV(88,0);
+		sv_upgrade(sv, SVt_PVMG);
+		sv_setsv(sv,PL_linestr);
+		(void)SvIOK_on(sv);
+		SvIV_set(sv, 0);
+		av_store(fileav, (I32)CopLINE(PL_curcop), sv);
+	    }
 	}
 
 	/* having changed the buffer, we must update PL_bufend */
@@ -790,24 +796,3 @@ S_scan_str(pTHX_ char *start, int keep_quoted, int keep_delims)
 	PL_lex_stuff = sv;
     return s;
 }
-
-/*
- * S_force_next
- * When the lexer realizes it knows the next token (for instance,
- * it is reordering tokens for the parser) then it can call S_force_next
- * to know what token to return the next time the lexer is called.  Caller
- * will need to set PL_nextval[], and possibly PL_expect to ensure the lexer
- * handles the token correctly.
- */
-
-STATIC void
-S_force_next(pTHX_ I32 type)
-{
-    PL_nexttype[PL_nexttoke] = type;
-    PL_nexttoke++;
-    if (PL_lex_state != LEX_KNOWNEXT) {
-  PL_lex_defer = PL_lex_state;
-  PL_lex_expect = PL_expect;
-  PL_lex_state = LEX_KNOWNEXT;
-    }
-}
